@@ -21,6 +21,8 @@ from rdflib.parser import Parser
 from rdflib.serializer import Serializer
 from uuid import uuid4
 from rdflib.namespace import DC, DCTERMS, DOAP, FOAF, SKOS, OWL, RDF, RDFS, VOID, XMLNS, XSD
+from json import dumps
+
 
 SHC = Namespace("http://data.shinc.co.uk/")
 NS = { 'foaf': FOAF, 'rdfs' : RDFS, "owl" : OWL, 'xsd' : XSD, 'rdf' : RDF, 'shc' : SHC}
@@ -450,10 +452,6 @@ class SOFEvent:
             return self.type == other.type and self.startdatetime == other.startdatetime and self.description == other.description
         return False
 
-    def __str__(self):
-        return str(self.id) + "\t" + str(self.type) + "\t" + str(self.startdatetime) + "\t" + str(self.description) + "\t" + str(self.enddatetime)
-        
-
 class SOF:
     def __init__(self, id, sofs=[], summary_sofs=[]):
         self.id = id
