@@ -1,7 +1,9 @@
 import unittest
 import rdflib
 import datetime
+import jsonpickle
 from datetime import timezone
+from json import dumps
 from rdflib import Namespace,URIRef, BNode, Literal,Graph, plugin
 from rdflib.parser import Parser
 from rdflib.serializer import Serializer
@@ -40,7 +42,6 @@ class SOFExtractorTestCase(unittest.TestCase):
         self.generator = SOFList('./sofs/sof-master-test.csv')
         self.generator.generate()
         
-
     def test_ocrextractor(self):
         extractor = SOFImageExtractor('./images/test_image.jpg','./tmpdata')
         result = extractor.extract()
@@ -117,6 +118,7 @@ class SOFExtractorTestCase(unittest.TestCase):
         assert sof.startdatetime.day == 20 and sof.startdatetime.month == 10 and sof.startdatetime.year == 2005 and sof.startdatetime.hour == 8 and sof.startdatetime.minute == 0
         assert sof.enddatetime.day == 20 and sof.enddatetime.month == 10 and sof.enddatetime.year == 2005 and sof.enddatetime.hour == 12 and sof.enddatetime.minute == 0
 
+
     def test_text_extractor(self):
         textextractor = SOFTextExtractor(self.generator)
         sofs = textextractor.extract(self.softext, starttext="Terminal / Comment", dateorder="DMY", timemask="hh:mm")
